/* SPDX-License-Identifier: LGPL-2.1-or-later */
#pragma once

int verb_switch_root(int argc, char *argv[], void *userdata);
